The arc lengths over specified intervals, in the domain of kernel density estimates, are matched.
alrKDE(beta, gamma, aly, q1, q2, type)Vector of regression parameters.
Design matrix.
A numerical vector of arc length segments to be matched to (same length as beta).
A vector of points (not quantiles) specifying the lower limit of the arc length segments.
A vector of points (not quantiles) specifying the upper limit of the arc length segments.
An integer specifying the bandwidth selection method, see bw.
Square root of the sum of squared differences between gamma*beta and aly (Eucledian distance).